Dialects — SQLAlchemy 1.3 Documentation

Release: 1.3.20 | Release Date: October 12, 2020

# SQLAlchemy 1.3 Documentation

# Dialects

The dialect is the system SQLAlchemy uses to communicate with various types of DBAPI implementations and databases. The sections that follow contain reference documentation and notes specific to the usage of each backend, as well as notes for the various DBAPIs.

All dialects require that an appropriate DBAPI driver is installed.

## Included Dialects

- PostgreSQL
- MySQL
- SQLite
- Oracle
- Microsoft SQL Server

## Included, but not currently supported dialects

The following dialects have implementations within SQLAlchemy, but they are not part of continuous integration testing nor are they actively developed. These dialects may be removed in future major releases.

- Firebird
- Sybase

## External Dialects

Currently maintained external dialect projects for SQLAlchemy include:

Database | Dialect
--- | ---
Amazon Redshift (via psycopg2) | sqlalchemy-redshift
Apache Drill | sqlalchemy-drill
Apache Druid | pydruid
Apache Hive and Presto | PyHive
Apache Solr | sqlalchemy-solr
CockroachDB | sqlalchemy-cockroachdb
CrateDB | crate-python
EXASolution | sqlalchemy_exasol
Elasticsearch (readonly) | elasticsearch-dbapi
Firebird | sqlalchemy-firebird
Google BigQuery | pybigquery
Google Sheets | gsheets
IBM DB2 and Informix | ibm-db-sa
Microsoft Access (via pyodbc) | sqlalchemy-access
Microsoft SQL Server (via python-tds) | sqlalchemy-tds
MonetDB | sqlalchemy-monetdb
SAP Hana | sqlalchemy-hana
SAP Sybase SQL Anywhere | sqlalchemy-sqlany
Snowflake | snowflake-sqlalchemy
Teradata Vantage | teradatasqlalchemy